NavDataCycle

Struct NavDataCycle 

#[non_exhaustive]
pub struct NavDataCycle { pub authority: NavDataAuthority, pub effective_on: NaiveDate, pub next_effective_on: NaiveDate, pub source: String, }
Publication-cycle metadata for a navigation-data snapshot.

Fields (Non-exhaustive)

This struct is marked as non-exhaustive
Non-exhaustive structs could have additional fields added in future. Therefore, non-exhaustive structs cannot be constructed in external crates using the traditional Struct { .. } syntax; cannot be matched against without a wildcard ..; and struct update syntax will not work.
authority: NavDataAuthority

Authority that published the data.

effective_on: NaiveDate

First date this snapshot is effective.

next_effective_on: NaiveDate

First date a successor cycle is effective.

source: String

URL or local product identifier used to create the snapshot.

Implementations

Source

impl NavDataCycle

pub fn faa_nasr(effective_on: NaiveDate) -> Result<Self, NavDataError>

FAA NASR cycle metadata from an effective date.

pub fn new( authority: NavDataAuthority, effective_on: NaiveDate, cycle_days: u64, source: impl Into<String>, ) -> Result<Self, NavDataError>

Cycle metadata from an authority, effective date, cycle length, and source identifier.

pub fn contains(&self, date: NaiveDate) -> bool

Whether date falls inside this effective cycle.